Install `isort` using your preferred Python package manager:

`pip3 install isort`

OR

`uv add isort`

OR

`poetry add isort`

OR

`pipenv install isort`

OR

For a fully isolated user installation you can use [pipx](https://github.com/pipxproject/pipx)

`pipx install isort`

<script id="asciicast-qZglwdh3YdoRHjtpxuNmQJehj" src="https://asciinema.org/a/qZglwdh3YdoRHjtpxuNmQJehj.js" async></script>

!!!tip
    If you want isort to act as a linter for projects, it probably makes sense to add isort as an explicit development dependency for each project that uses it. If, on the other hand, you are an individual developer simply using isort as a personal tool to clean up your own commits, a global or user level installation makes sense. Both are seamlessly supported on a single machine.
